==> munit-remote-1.2.0-sources.jar: org/mule/munit/remote/path/ApplicationPathCounter.java <==
/*
 * Copyright (c) 2015 MuleSoft, Inc. This software is protected under international
 * copyright law. All use of this software is subject to MuleSoft's Master Subscription
 * Agreement (or other master license agreement) separately entered into in writing between
 * you and MuleSoft. If such an agreement is not in place, you may not use the software.
 */
package org.mule.munit.remote.path;

import org.mule.api.MuleContext;
import org.mule.munit.runner.simple.MunitSimpleRunnerAction;

import java.util.HashSet;
import java.util.Set;

public class ApplicationPathCounter implements MunitSimpleRunnerAction {

    private Set<String> flowPaths;
    private Set<String> subFlowPaths;
    private Set<String> batchPaths;

    private Boolean executed = false;

    public void execute(MuleContext context) {
        SimplePathBuilder pathBuilder = new SimplePathBuilder(context);
        flowPaths = new HashSet<String>(pathBuilder.buildFlowPathsMap().values());
        subFlowPaths = new HashSet<String>(pathBuilder.buildSubFlowPathsMap().values());
        batchPaths = new HashSet<String>(pathBuilder.buildBatchPathsMap().values());

        executed = true;
    }

    public Set<String> getFlowPaths() {
        validateState();
        return flowPaths;
    }

    public Set<String> getSubFlowPaths() {
        validateState();
        return subFlowPaths;
    }

    public Set<String> getBatchPaths() {
        validateState();
        return batchPaths;
    }

    private void validateState() {
        if (false == executed) {
            throw new IllegalStateException("No count has been executed");
        }
    }


}

==> munit-remote-1.3.1-sources.jar: org/mule/munit/remote/path/ApplicationPathCounter.java <==
/*
 * Copyright (c) 2015 MuleSoft, Inc. This software is protected under international
 * copyright law. All use of this software is subject to MuleSoft's Master Subscription
 * Agreement (or other master license agreement) separately entered into in writing between
 * you and MuleSoft. If such an agreement is not in place, you may not use the software.
 */
package org.mule.munit.remote.path;

import org.mule.api.MuleContext;
import org.mule.munit.plugins.coverage.PathBuilder;
import org.mule.munit.runner.simple.MunitSimpleRunnerAction;

import java.util.HashSet;
import java.util.Set;

public class ApplicationPathCounter implements MunitSimpleRunnerAction {

    private Set<String> flowPaths;
    private Set<String> subFlowPaths;
    private Set<String> batchPaths;

    private Boolean executed = false;

    public void execute(MuleContext context) {
        PathBuilder pathBuilder = new PathBuilder(context);
        flowPaths = new HashSet<String>(pathBuilder.buildFlowPathsMap().values());
        subFlowPaths = new HashSet<String>(pathBuilder.buildSubFlowPathsMap().values());
        batchPaths = new HashSet<String>(pathBuilder.buildBatchPathsMap().values());

        executed = true;
    }

    public Set<String> getFlowPaths() {
        validateState();
        return flowPaths;
    }

    public Set<String> getSubFlowPaths() {
        validateState();
        return subFlowPaths;
    }

    public Set<String> getBatchPaths() {
        validateState();
        return batchPaths;
    }

    private void validateState() {
        if (false == executed) {
            throw new IllegalStateException("No count has been executed");
        }
    }


}
